import re
import requests
import sys


class Landing:
    """Class which connect and control the connection to server"""

    def __init__(self, address):
        """Connects to server, starts the landing"""

        self.address = address
        self.landing_id = None
        self.position_X = None
        self.position_Y = None
        self.velocity_X = None
        self.velocity_Y = None
        self.fuel = None
        self.landing_area = None

        self.state = 0  # 0: pre-flight, 1: in-flight, 2: landed, 3: crash

        self.update()

    def update(self, up=0, left=0, right=0):
        """Updates state from server"""
        try:
            if self.landing_id is None:
                settings = self._request("start")
                self.state = 1
            else:
                settings = self._request("stav?id=%d&nahoru=%d&doleva=%d&doprava=%d" % (self.landing_id, up, left, right))
        except ConnectionError:
            print("Nepodařilo se navázat spojení se serverem %s." % self.address)
            sys.exit(1)

        settings = re.split(" |\r\n", settings)
        if settings[0] == "Zdar!":
            print("ZDAR")
            self.state = 2
        elif settings[0] == "Krach!":
            print("KRACH")
            self.state = 3
        else:
            self.landing_id = int(settings[0])
            self.position_X = float(settings[1])
            self.position_Y = float(settings[2])
            self.velocity_X = float(settings[3])
            self.velocity_Y = float(settings[4])
            self.fuel = float(settings[5])
            self.landing_area = (float(settings[6]), float(settings[7]))

    def _request(self, request):
        """Returns content of arbitrary request answer from the server"""
        content = requests.get(self.address+"/"+request).content
        return content.decode("utf-8")
