"""GUI for controlling server
Usage python3 manual_landing.py"""
import landing
import sys

import pygame
from pygame.locals import *


def render_velocity(myfont, velocity_x, velocity_y):
    msg = "RYCHLOST_X: " + str(velocity_x) + " RYCHLOST_Y: " + str(velocity_y)
    return myfont.render(msg, 1, BLACK)


SCALE = 2
SIZE = 200

# Initialize useful globals
BLACK = pygame.Color(0, 0, 0)
WHITE = pygame.Color(255, 255, 255)
lander_img = pygame.image.load("lunar_lander.png")
lander_img = pygame.transform.scale(lander_img, (20*SCALE, 20*SCALE))
motor_right = pygame.image.load("left.png")
motor_right = pygame.transform.scale(motor_right, (20*SCALE, 20*SCALE))
motor_left = pygame.image.load("right.png")
motor_left = pygame.transform.scale(motor_left, (20*SCALE, 20*SCALE))
motor_up = pygame.image.load("up.png")
motor_up = pygame.transform.scale(motor_up, (20*SCALE, 20*SCALE))

# Get server address
server = input("Zadejte adresu a port serveru. Výchozí: localhost:8000\n")
if server == "":
    server = "http://localhost:8000"
else:
    server = "http://" + server

input("Libovolna klavesa pro start.")

while True:
    game = landing.Landing(server)
    pygame.init()
    myfont = pygame.font.SysFont("monospace", 13)
    pygame.font.init()
    fps_clock = pygame.time.Clock()
    window = pygame.display.set_mode((SIZE*SCALE, SIZE*SCALE))

    up = left = right = 0

    while game.state == 1:
        # In-flight
        window.fill(WHITE)

        # Landing area
        pygame.draw.rect(window, BLACK, (game.landing_area[0], SIZE*SCALE-2*SCALE, game.landing_area[1], 2*SCALE))

        # Controls
        for event in pygame.event.get():
            if event.type == KEYDOWN:
                if event.key == K_UP:
                    up = not up
                if event.key == K_RIGHT:
                    right = not right
                if event.key == K_LEFT:
                    left = not left

        # Render
        window.blit(lander_img, ((game.position_X-10)*SCALE, (SIZE-game.position_Y-10)*SCALE))

        if up:
            window.blit(motor_up, ((game.position_X-10)*SCALE, (SIZE-game.position_Y+10)*SCALE))
        if left:
            window.blit(motor_left, ((game.position_X+7.5) * SCALE, (SIZE - game.position_Y-10) * SCALE))
        if right:
            window.blit(motor_right, ((game.position_X - 27.5) * SCALE, (SIZE - game.position_Y - 10) * SCALE))

        # Text update
        window.blit(render_velocity(myfont, game.velocity_X, game.velocity_Y), (0, 0))
        window.blit(myfont.render("Palivo: "+str(game.fuel), 1, BLACK), (0, (SIZE-10)*SCALE))

        # Post updates to server
        game.update(up, left, right)

        #Next frame
        pygame.display.update()
        fps_clock.tick(30)

    if game.state in [2, 3]:
        # Post-flight
        waiting = True
        while waiting:
            for event in pygame.event.get():
                if event.type == KEYDOWN:
                    if event.key == K_e:
                        sys.exit(0)
                    else:
                        waiting = False
            if game.state == 2:
                msg = "ZDAR!"
                window.blit(myfont.render(msg, 1, BLACK), (0, 10*SCALE))
            if game.state == 3:
                msg = "KRACH!"
                window.blit(myfont.render(msg, 1, BLACK), (0, 10*SCALE))
            msg = "Stisknete libovolne tlacitko pro novou hru,"
            window.blit(myfont.render(msg, 1, BLACK), (0, 15*SCALE))
            msg = "E pro konec."
            window.blit(myfont.render(msg, 1, BLACK), (0, 20*SCALE))
            pygame.display.update()
            fps_clock.tick(30)
